@@ -1,5 +1,5 @@
 package Defaults::Modern;
-$Defaults::Modern::VERSION = '0.009003';
+$Defaults::Modern::VERSION = '0.010001';
 use v5.14;
 
 use strictures 2;
@@ -50,6 +50,11 @@ sub import {
   PARAM: for my $item (@_) {
     my $current = $idx++;
     if ($item eq 'with_types' || $item eq '-with_types') {
+      # backwards-compat ; may go away someday
+      Carp::carp(
+        "'with_types' option is deprecated; ",
+        "'use TYPELIB -all' after 'use Defaults::Modern;' instead"
+      );
       $typelibs = $_[$idx];
       splice @_, $current, 2;
       if (ref $typelibs) {
@@ -62,7 +67,7 @@ sub import {
     }
 
     my $opt = lc($item =~ s/^(?:[-:])//r);
-    Carp::croak "$class does not export $opt" unless $known->{$opt};
+    Carp::croak("$class does not export $opt") unless $known->{$opt};
 
     if ($opt eq 'all') {
       $params{$_} = 1 for grep {; $_ ne 'all' } keys %$known;
@@ -112,7 +117,7 @@ sub import {
     },
   };
 
-  Function::Parameters->import::into( $pkg,
+  Function::Parameters->import(
     +{
       fun => {
         name                  => 'optional',
@@ -195,11 +200,11 @@ Defaults::Modern - Yet another approach to modernistic Perl
     use Moo;
 
     has myarray => (
-      isa => ArrayObj,
-      is  => 'ro',
+      is      => 'ro',
+      isa     => ArrayObj,
       writer  => '_set_myarray',
       coerce  => 1,
-      default => sub { [] },
+      builder => sub { [] },
     );
 
     # Method with optional positional param and implicit $self ->
@@ -258,7 +263,9 @@ B<immhash_of>)
 
 =item *
 
-B<fun> and B<method> keywords from L<Function::Parameters>
+B<fun> and B<method> keywords from L<Function::Parameters> configured to
+accept L<Type::Tiny> types (amongst other reasonably sane defaults including
+arity checks)
 
 =item *
 
@@ -297,18 +304,6 @@ L<true>.pm so you can skip adding '1;' to all of your modules
 
 =back
 
-If you want to automatically load (shown here with the '-all' import tag, as
-well) and register other L<Type::Registry> compatible libraries (see
-L<Type::Library>), they can be specified at import time:
-
-  use Defaults::Modern
-    -all,
-    -with_types => [ 'Types::Mine' ],
-
-This feature is unnecessary with L<Type::Tiny> version 1.x and higher, which
-will automatically register L<Type::Library>-based types in the caller's
-L<Type::Registry>.
-
 If you import the tag C<autobox_lists>, ARRAY and HASH type references are autoboxed
 via L<List::Objects::WithUtils>:
 
@@ -320,6 +315,7 @@ automatically imported:
 
   use Defaults::Modern;
   use Moo;
+  use MooX::TypeTiny;   # recommended for faster inline type checks
 
   has foo => (
     is  => 'ro',
@@ -328,9 +324,14 @@ automatically imported:
     default => sub { [] },
   );
 
-(If you're building classes, you may want to look into L<namespace::clean> /
+If you're building classes, you may want to look into L<namespace::clean> /
 L<namespace::sweep> or similar -- L<Defaults::Modern> imports an awful lot of
-Stuff. L<Moops> may be nicer to work with.)
+Stuff:
+
+  use Defaults::Modern;
+  use Moo;
+  use namespace::clean;
+  # ...
 
 =head1 SEE ALSO
 
